@@ -17,25 +17,46 @@ import tempfile
 import warnings
 from contextlib import contextmanager
 from pathlib import Path
-from typing import Optional
+from typing import Any, Dict, Iterator, List, Optional
+
+import platformdirs
+
+from jupyter_core.utils import deprecation
 
 pjoin = os.path.join
 
+# Capitalize Jupyter in paths only on Windows and MacOS
+APPNAME = "Jupyter" if sys.platform in ("win32", "darwin") else "jupyter"
+
 # UF_HIDDEN is a stat flag not defined in the stat module.
 # It is used by BSD to indicate hidden files.
 UF_HIDDEN = getattr(stat, "UF_HIDDEN", 32768)
 
 
-def envset(name):
-    """Return True if the given environment variable is set
+def envset(name: str, default: Optional[bool] = False) -> Optional[bool]:
+    """Return the boolean value of a given environment variable.
 
     An environment variable is considered set if it is assigned to a value
     other than 'no', 'n', 'false', 'off', '0', or '0.0' (case insensitive)
+
+    If the environment variable is not defined, the default value is returned.
     """
-    return os.environ.get(name, "no").lower() not in ["no", "n", "false", "off", "0", "0.0"]
+    if name not in os.environ:
+        return default
+
+    return os.environ[name].lower() not in ["no", "n", "false", "off", "0", "0.0"]
 
 
-def get_home_dir():
+def use_platform_dirs() -> bool:
+    """Determine if platformdirs should be used for system-specific paths.
+
+    We plan for this to default to False in jupyter_core version 5 and to True
+    in jupyter_core version 6.
+    """
+    return envset("JUPYTER_PLATFORM_DIRS", False)  # type:ignore[return-value]
+
+
+def get_home_dir() -> str:
     """Get the real path of the home directory"""
     homedir = os.path.expanduser("~")
     # Next line will make things work even when /home/ is a symlink to
@@ -44,10 +65,59 @@ def get_home_dir():
     return homedir
 
 
-_dtemps: dict = {}
+_dtemps: Dict[str, str] = {}
 
 
-def _mkdtemp_once(name):
+def _do_i_own(path: str) -> bool:
+    """Return whether the current user owns the given path"""
+    p = Path(path).resolve()
+
+    # walk up to first existing parent
+    while not p.exists() and p != p.parent:
+        p = p.parent
+
+    # simplest check: owner by name
+    # not always implemented or available
+    try:
+        return p.owner() == os.getlogin()
+    except (NotImplementedError, OSError):
+        pass
+
+    if hasattr(os, 'geteuid'):
+        try:
+            st = p.stat()
+            return st.st_uid == os.geteuid()
+        except (NotImplementedError, OSError):
+            # geteuid not always implemented
+            pass
+
+    # no ownership checks worked, check write access
+    return os.access(p, os.W_OK)
+
+
+def prefer_environment_over_user() -> bool:
+    """Determine if environment-level paths should take precedence over user-level paths."""
+    # If JUPYTER_PREFER_ENV_PATH is defined, that signals user intent, so return its value
+    if "JUPYTER_PREFER_ENV_PATH" in os.environ:
+        return envset("JUPYTER_PREFER_ENV_PATH")  # type:ignore[return-value]
+
+    # If we are in a Python virtualenv, default to True (see https://docs.python.org/3/library/venv.html#venv-def)
+    if sys.prefix != sys.base_prefix and _do_i_own(sys.prefix):
+        return True
+
+    # If sys.prefix indicates Python comes from a conda/mamba environment that is not the root environment, default to True
+    if (
+        "CONDA_PREFIX" in os.environ
+        and sys.prefix.startswith(os.environ["CONDA_PREFIX"])
+        and os.environ.get("CONDA_DEFAULT_ENV", "base") != "base"
+        and _do_i_own(sys.prefix)
+    ):
+        return True
+
+    return False
+
+
+def _mkdtemp_once(name: str) -> str:
     """Make or reuse a temporary directory.
 
     If this is called with the same name in the same process, it will return
@@ -60,10 +130,11 @@ def _mkdtemp_once(name):
         return d
 
 
-def jupyter_config_dir():
+def jupyter_config_dir() -> str:
     """Get the Jupyter config directory for this platform and user.
 
-    Returns JUPYTER_CONFIG_DIR if defined, else ~/.jupyter
+    Returns JUPYTER_CONFIG_DIR if defined, otherwise the appropriate
+    directory for the platform.
     """
 
     env = os.environ
@@ -73,11 +144,14 @@ def jupyter_config_dir():
     if env.get("JUPYTER_CONFIG_DIR"):
         return env["JUPYTER_CONFIG_DIR"]
 
+    if use_platform_dirs():
+        return platformdirs.user_config_dir(APPNAME, appauthor=False)
+
     home_dir = get_home_dir()
     return pjoin(home_dir, ".jupyter")
 
 
-def jupyter_data_dir():
+def jupyter_data_dir() -> str:
     """Get the config directory for Jupyter data files for this platform and user.
 
     These are non-transient, non-configuration files.
@@ -89,6 +163,9 @@ def jupyter_data_dir():
     if env.get("JUPYTER_DATA_DIR"):
         return env["JUPYTER_DATA_DIR"]
 
+    if use_platform_dirs():
+        return platformdirs.user_data_dir(APPNAME, appauthor=False)
+
     home = get_home_dir()
 
     if sys.platform == "darwin":
@@ -107,7 +184,7 @@ def jupyter_data_dir():
         return pjoin(xdg, "jupyter")
 
 
-def jupyter_runtime_dir():
+def jupyter_runtime_dir() -> str:
     """Return the runtime dir for transient jupyter files.
 
     Returns JUPYTER_RUNTIME_DIR if defined.
@@ -123,22 +200,34 @@ def jupyter_runtime_dir():
     return pjoin(jupyter_data_dir(), "runtime")
 
 
-if os.name == "nt":
-    programdata = os.environ.get("PROGRAMDATA", None)
-    if programdata:
-        SYSTEM_JUPYTER_PATH = [pjoin(programdata, "jupyter")]
-    else:  # PROGRAMDATA is not defined by default on XP.
-        SYSTEM_JUPYTER_PATH = [os.path.join(sys.prefix, "share", "jupyter")]
+if use_platform_dirs():
+    SYSTEM_JUPYTER_PATH = platformdirs.site_data_dir(
+        APPNAME, appauthor=False, multipath=True
+    ).split(os.pathsep)
 else:
-    SYSTEM_JUPYTER_PATH = [
-        "/usr/local/share/jupyter",
-        "/usr/share/jupyter",
-    ]
+    deprecation(
+        "Jupyter is migrating its paths to use standard platformdirs\n"
+        + "given by the platformdirs library.  To remove this warning and\n"
+        + "see the appropriate new directories, set the environment variable\n"
+        + "`JUPYTER_PLATFORM_DIRS=1` and then run `jupyter --paths`.\n"
+        + "The use of platformdirs will be the default in `jupyter_core` v6"
+    )
+    if os.name == "nt":
+        programdata = os.environ.get("PROGRAMDATA", None)
+        if programdata:
+            SYSTEM_JUPYTER_PATH = [pjoin(programdata, "jupyter")]
+        else:  # PROGRAMDATA is not defined by default on XP.
+            SYSTEM_JUPYTER_PATH = [os.path.join(sys.prefix, "share", "jupyter")]
+    else:
+        SYSTEM_JUPYTER_PATH = [
+            "/usr/local/share/jupyter",
+            "/usr/share/jupyter",
+        ]
 
-ENV_JUPYTER_PATH = [os.path.join(sys.prefix, "share", "jupyter")]
+ENV_JUPYTER_PATH: List[str] = [os.path.join(sys.prefix, "share", "jupyter")]
 
 
-def jupyter_path(*subdirs):
+def jupyter_path(*subdirs: str) -> List[str]:
     """Return a list of directories to search for data files
 
     JUPYTER_PATH environment variable has highest priority.
@@ -160,7 +249,7 @@ def jupyter_path(*subdirs):
     ['~/.local/jupyter/kernels', '/usr/local/share/jupyter/kernels']
     """
 
-    paths: list = []
+    paths: List[str] = []
 
     # highest priority is explicit environment variable
     if os.environ.get("JUPYTER_PATH"):
@@ -184,7 +273,7 @@ def jupyter_path(*subdirs):
 
     env = [p for p in ENV_JUPYTER_PATH if p not in SYSTEM_JUPYTER_PATH]
 
-    if envset("JUPYTER_PREFER_ENV_PATH"):
+    if prefer_environment_over_user():
         paths.extend(env)
         paths.extend(user)
     else:
@@ -200,22 +289,26 @@ def jupyter_path(*subdirs):
     return paths
 
 
-if os.name == "nt":
-    programdata = os.environ.get("PROGRAMDATA", None)
-    if programdata:
-        SYSTEM_CONFIG_PATH = [os.path.join(programdata, "jupyter")]
-    else:  # PROGRAMDATA is not defined by default on XP.
-        SYSTEM_CONFIG_PATH = []
+if use_platform_dirs():
+    SYSTEM_CONFIG_PATH = platformdirs.site_config_dir(
+        APPNAME, appauthor=False, multipath=True
+    ).split(os.pathsep)
 else:
-    SYSTEM_CONFIG_PATH = [
-        "/usr/local/etc/jupyter",
-        "/etc/jupyter",
-    ]
-
-ENV_CONFIG_PATH = [os.path.join(sys.prefix, "etc", "jupyter")]
+    if os.name == "nt":
+        programdata = os.environ.get("PROGRAMDATA", None)
+        if programdata:
+            SYSTEM_CONFIG_PATH = [os.path.join(programdata, "jupyter")]
+        else:  # PROGRAMDATA is not defined by default on XP.
+            SYSTEM_CONFIG_PATH = []
+    else:
+        SYSTEM_CONFIG_PATH = [
+            "/usr/local/etc/jupyter",
+            "/etc/jupyter",
+        ]
+ENV_CONFIG_PATH: List[str] = [os.path.join(sys.prefix, "etc", "jupyter")]
 
 
-def jupyter_config_path():
+def jupyter_config_path() -> List[str]:
     """Return the search path for Jupyter config files as a list.
 
     If the JUPYTER_PREFER_ENV_PATH environment variable is set, the
@@ -229,7 +322,7 @@ def jupyter_config_path():
         # jupyter_config_dir makes a blank config when JUPYTER_NO_CONFIG is set.
         return [jupyter_config_dir()]
 
-    paths: list = []
+    paths: List[str] = []
 
     # highest priority is explicit environment variable
     if os.environ.get("JUPYTER_CONFIG_PATH"):
@@ -253,7 +346,7 @@ def jupyter_config_path():
 
     env = [p for p in ENV_CONFIG_PATH if p not in SYSTEM_CONFIG_PATH]
 
-    if envset("JUPYTER_PREFER_ENV_PATH"):
+    if prefer_environment_over_user():
         paths.extend(env)
         paths.extend(user)
     else:
@@ -265,7 +358,7 @@ def jupyter_config_path():
     return paths
 
 
-def exists(path):
+def exists(path: str) -> bool:
     """Replacement for `os.path.exists` which works for host mapped volumes
     on Windows containers
     """
@@ -276,7 +369,7 @@ def exists(path):
     return True
 
 
-def is_file_hidden_win(abs_path, stat_res=None):
+def is_file_hidden_win(abs_path: str, stat_res: Optional[Any] = None) -> bool:
     """Is a file hidden?
 
     This only checks the file itself; it should be called in combination with
@@ -304,7 +397,7 @@ def is_file_hidden_win(abs_path, stat_res=None):
             raise
 
     try:
-        if stat_res.st_file_attributes & stat.FILE_ATTRIBUTE_HIDDEN:  # type:ignore[attr-defined]
+        if stat_res.st_file_attributes & stat.FILE_ATTRIBUTE_HIDDEN:  # type:ignore
             return True
     except AttributeError:
         # allow AttributeError on PyPy for Windows
@@ -318,7 +411,7 @@ def is_file_hidden_win(abs_path, stat_res=None):
     return False
 
 
-def is_file_hidden_posix(abs_path, stat_res=None):
+def is_file_hidden_posix(abs_path: str, stat_res: Optional[Any] = None) -> bool:
     """Is a file hidden?
 
     This only checks the file itself; it should be called in combination with
@@ -346,7 +439,7 @@ def is_file_hidden_posix(abs_path, stat_res=None):
             raise
 
     # check that dirs can be listed
-    if stat.S_ISDIR(stat_res.st_mode):
+    if stat.S_ISDIR(stat_res.st_mode):  # type:ignore[misc]
         # use x-access, not actual listing, in case of slow/large listings
         if not os.access(abs_path, os.X_OK | os.R_OK):
             return True
@@ -364,7 +457,7 @@ else:
     is_file_hidden = is_file_hidden_posix
 
 
-def is_hidden(abs_path, abs_root=""):
+def is_hidden(abs_path: str, abs_root: str = "") -> bool:
     """Is a file hidden or contained in a hidden directory?
 
     This will start with the rightmost path element and work backwards to the
@@ -384,7 +477,10 @@ def is_hidden(abs_path, abs_root=""):
         The absolute path of the root directory in which hidden directories
         should be checked for.
     """
-    if os.path.normpath(abs_path) == os.path.normpath(abs_root):
+    abs_path = os.path.normpath(abs_path)
+    abs_root = os.path.normpath(abs_root)
+
+    if abs_path == abs_root:
         return False
 
     if is_file_hidden(abs_path):
@@ -415,7 +511,7 @@ def is_hidden(abs_path, abs_root=""):
     return False
 
 
-def win32_restrict_file_to_user(fname):
+def win32_restrict_file_to_user(fname: str) -> None:
     """Secure a windows file to read-only access for the user.
     Follows guidance from win32 library creator:
     http://timgolden.me.uk/python/win32_how_do_i/add-security-to-a-file.html
@@ -458,7 +554,7 @@ def win32_restrict_file_to_user(fname):
     win32security.SetFileSecurity(fname, win32security.DACL_SECURITY_INFORMATION, sd)
 
 
-def _win32_restrict_file_to_user_ctypes(fname):
+def _win32_restrict_file_to_user_ctypes(fname: str) -> None:
     """Secure a windows file to read-only access for the user.
 
     Follows guidance from win32 library creator:
@@ -832,7 +928,7 @@ def _win32_restrict_file_to_user_ctypes(fname):
     SetFileSecurity(fname, DACL_SECURITY_INFORMATION, SelfRelativeSD)
 
 
-def get_file_mode(fname):
+def get_file_mode(fname: str) -> int:
     """Retrieves the file mode corresponding to fname in a filesystem-tolerant manner.
 
     Parameters
@@ -855,7 +951,7 @@ allow_insecure_writes = os.getenv("JUPYTER_ALLOW_INSECURE_WRITES", "false").lowe
 
 
 @contextmanager
-def secure_write(fname, binary=False):
+def secure_write(fname: str, binary: bool = False) -> Iterator[Any]:
     """Opens a file in the most restricted pattern available for
     writing content. This limits the file mode to `0o0600` and yields
     the resulting opened filed handle.
@@ -909,7 +1005,7 @@ def secure_write(fname, binary=False):
         yield f
 
 
-def issue_insecure_write_warning():
+def issue_insecure_write_warning() -> None:
     def format_warning(msg, *args, **kwargs):
         return str(msg) + "\n"
 
